export const ATTACH_CD = 'Attach CD-ROM';
export const NO_BOOTABLE_ATTACHED_DISK_ERROR = 'A bootable attached disk could not be found';
export const SELECT_BOOTABLE_DISK = '--- Select Bootable Disk ---';
